==> r2r-0.2.46-py3-none-any.whl: r2r/base/__init__.py <==
from .abstractions.base import AsyncSyncMeta, UserStats, syncable
from .abstractions.document import (
    DataType,
    Document,
    DocumentInfo,
    DocumentType,
    Entity,
    Extraction,
    ExtractionType,
    Fragment,
    FragmentType,
    KGExtraction,
    Triple,
    extract_entities,
    extract_triples,
)
from .abstractions.llama_abstractions import VectorStoreQuery
from .abstractions.llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    RAGCompletion,
)
from .abstractions.prompt import Prompt
from .abstractions.search import (
    AggregateSearchResult,
    KGSearchRequest,
    KGSearchResult,
    KGSearchSettings,
    VectorSearchRequest,
    VectorSearchResult,
    VectorSearchSettings,
)
from .abstractions.vector import Vector, VectorEntry, VectorType
from .logging.kv_logger import (
    KVLoggingSingleton,
    LocalKVLoggingProvider,
    LoggingConfig,
    PostgresKVLoggingProvider,
    PostgresLoggingConfig,
    RedisKVLoggingProvider,
    RedisLoggingConfig,
)
from .logging.log_processor import (
    AnalysisTypes,
    FilterCriteria,
    LogAnalytics,
    LogAnalyticsConfig,
    LogProcessor,
)
from .logging.run_manager import RunManager, manage_run
from .parsers import AsyncParser
from .pipeline.base_pipeline import AsyncPipeline
from .pipes.base_pipe import AsyncPipe, AsyncState, PipeType
from .providers.embedding_provider import EmbeddingConfig, EmbeddingProvider
from .providers.eval_provider import EvalConfig, EvalProvider
from .providers.kg_provider import KGConfig, KGProvider
from .providers.llm_provider import LLMConfig, LLMProvider
from .providers.prompt_provider import PromptConfig, PromptProvider
from .providers.vector_db_provider import VectorDBConfig, VectorDBProvider
from .utils import (
    EntityType,
    RecursiveCharacterTextSplitter,
    Relation,
    TextSplitter,
    format_entity_types,
    format_relations,
    generate_id_from_label,
    generate_run_id,
    increment_version,
    run_pipeline,
    to_async_generator,
)

__all__ = [
    # Logging
    "AsyncParser",
    "AnalysisTypes",
    "LogAnalytics",
    "LogAnalyticsConfig",
    "LogProcessor",
    "LoggingConfig",
    "LocalKVLoggingProvider",
    "PostgresLoggingConfig",
    "PostgresKVLoggingProvider",
    "RedisLoggingConfig",
    "AsyncSyncMeta",
    "syncable",
    "RedisKVLoggingProvider",
    "KVLoggingSingleton",
    "RunManager",
    "manage_run",
    # Abstractions
    "VectorEntry",
    "VectorType",
    "Vector",
    "VectorSearchRequest",
    "VectorSearchResult",
    "VectorSearchSettings",
    "KGSearchRequest",
    "KGSearchResult",
    "KGSearchSettings",
    "AggregateSearchResult",
    "AsyncPipe",
    "PipeType",
    "AsyncState",
    "AsyncPipe",
    "Prompt",
    "DataType",
    "DocumentType",
    "Document",
    "DocumentInfo",
    "Extraction",
    "ExtractionType",
    "Fragment",
    "FragmentType",
    "extract_entities",
    "Entity",
    "extract_triples",
    "Triple",
    "KGExtraction",
    "UserStats",
    # Pipelines
    "AsyncPipeline",
    # Providers
    "EmbeddingConfig",
    "EmbeddingProvider",
    "EvalConfig",
    "EvalProvider",
    "PromptConfig",
    "PromptProvider",
    "GenerationConfig",
    "RAGCompletion",
    "VectorStoreQuery",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "LLMConfig",
    "LLMProvider",
    "VectorDBConfig",
    "VectorDBProvider",
    "KGProvider",
    "KGConfig",
    # Other
    "FilterCriteria",
    "TextSplitter",
    "RecursiveCharacterTextSplitter",
    "to_async_generator",
    "EntityType",
    "Relation",
    "format_entity_types",
    "format_relations",
    "increment_version",
    "run_pipeline",
    "generate_run_id",
    "generate_id_from_label",
]

==> r2r-0.2.71-py3-none-any.whl: r2r/base/__init__.py <==
from .abstractions.assistant import (
    Assistant,
    AssistantConfig,
    Conversation,
    Message,
    Tool,
)
from .abstractions.base import AsyncSyncMeta, syncable
from .abstractions.document import (
    DataType,
    Document,
    DocumentInfo,
    DocumentType,
    Entity,
    Extraction,
    ExtractionType,
    Fragment,
    FragmentType,
    KGExtraction,
    Triple,
    extract_entities,
    extract_triples,
)
from .abstractions.embedding import EmbeddingPurpose
from .abstractions.exception import R2RDocumentProcessingError, R2RException
from .abstractions.llama_abstractions import VectorStoreQuery
from .abstractions.llm import (
    GenerationConfig,
    LLMChatCompletion,
    LLMChatCompletionChunk,
    RAGCompletion,
)
from .abstractions.prompt import Prompt
from .abstractions.search import (
    AggregateSearchResult,
    KGSearchRequest,
    KGSearchResult,
    KGSearchSettings,
    VectorSearchRequest,
    VectorSearchResult,
    VectorSearchSettings,
)
from .abstractions.user import Token, TokenData, User, UserCreate, UserStats
from .abstractions.vector import Vector, VectorEntry, VectorType
from .logging.kv_logger import (
    KVLoggingSingleton,
    LocalKVLoggingProvider,
    LoggingConfig,
    PostgresKVLoggingProvider,
    PostgresLoggingConfig,
    RedisKVLoggingProvider,
    RedisLoggingConfig,
)
from .logging.log_processor import (
    AnalysisTypes,
    FilterCriteria,
    LogAnalytics,
    LogAnalyticsConfig,
    LogProcessor,
)
from .logging.run_manager import RunManager, manage_run
from .parsers import AsyncParser
from .pipeline.base_pipeline import AsyncPipeline
from .pipes.base_pipe import AsyncPipe, AsyncState, PipeType
from .providers.auth import AuthConfig, AuthProvider
from .providers.crypto import CryptoConfig, CryptoProvider
from .providers.database import (
    DatabaseConfig,
    DatabaseProvider,
    RelationalDatabaseProvider,
    VectorDatabaseProvider,
)
from .providers.embedding import EmbeddingConfig, EmbeddingProvider
from .providers.eval import EvalConfig, EvalProvider
from .providers.kg import KGConfig, KGProvider, update_kg_prompt
from .providers.llm import LLMConfig, LLMProvider
from .providers.prompt import PromptConfig, PromptProvider
from .utils import (
    EntityType,
    RecursiveCharacterTextSplitter,
    Relation,
    TextSplitter,
    format_entity_types,
    format_relations,
    generate_id_from_label,
    generate_run_id,
    increment_version,
    run_pipeline,
    to_async_generator,
)

__all__ = [
    # Logging
    "AsyncParser",
    "AnalysisTypes",
    "LogAnalytics",
    "LogAnalyticsConfig",
    "LogProcessor",
    "LoggingConfig",
    "LocalKVLoggingProvider",
    "PostgresLoggingConfig",
    "PostgresKVLoggingProvider",
    "RedisLoggingConfig",
    "AsyncSyncMeta",
    "syncable",
    "Assistant",
    "AssistantConfig",
    "Tool",
    "Message",
    "Conversation",
    "RedisKVLoggingProvider",
    "KVLoggingSingleton",
    "RunManager",
    "manage_run",
    # Abstractions
    "VectorEntry",
    "VectorType",
    "Vector",
    "VectorSearchRequest",
    "VectorSearchResult",
    "VectorSearchSettings",
    "Token",
    "TokenData",
    "User",
    "UserCreate",
    "KGSearchRequest",
    "KGSearchResult",
    "KGSearchSettings",
    "AggregateSearchResult",
    "AsyncPipe",
    "PipeType",
    "AsyncState",
    "AsyncPipe",
    "Prompt",
    "DataType",
    "DocumentType",
    "Document",
    "DocumentInfo",
    "Extraction",
    "ExtractionType",
    "Fragment",
    "FragmentType",
    "extract_entities",
    "Entity",
    "extract_triples",
    "EmbeddingPurpose",
    "R2RException",
    "R2RDocumentProcessingError",
    "Triple",
    "KGExtraction",
    "UserStats",
    # Pipelines
    "AsyncPipeline",
    # Providers
    "EmbeddingConfig",
    "EmbeddingProvider",
    "EvalConfig",
    "EvalProvider",
    "PromptConfig",
    "PromptProvider",
    "GenerationConfig",
    "RAGCompletion",
    "VectorStoreQuery",
    "LLMChatCompletion",
    "LLMChatCompletionChunk",
    "LLMConfig",
    "LLMProvider",
    "AuthConfig",
    "AuthProvider",
    "CryptoConfig",
    "CryptoProvider",
    "DatabaseConfig",
    "DatabaseProvider",
    "VectorDatabaseProvider",
    "RelationalDatabaseProvider",
    "KGProvider",
    "KGConfig",
    "update_kg_prompt",
    # Other
    "FilterCriteria",
    "TextSplitter",
    "RecursiveCharacterTextSplitter",
    "to_async_generator",
    "EntityType",
    "Relation",
    "format_entity_types",
    "format_relations",
    "increment_version",
    "run_pipeline",
    "generate_run_id",
    "generate_id_from_label",
]
